from typing import List
from re import compile, Pattern
from hashlib import sha1


class SHA1(object):
    NAME: str = "SHA1"
    EXT: List[str] = [".sha1"]
    SYNTAX: List[Pattern] = [compile(r"^;*$"), compile(r"^.* [0-9a-fA-F]{40}$")]
    REGEX: Pattern = compile(r"[0-9a-fA-F]{40}")
    NULL: str = "DA39A3EE5E6B4B0D3255BFEF95601890AFD80709"

    def __init__(self):
        self.cksum = sha1(usedforsecurity=False)

    def gensum(self, data: bytes):
        self.cksum.update(data)

    def reset(self):
        self.__init__()

    def format(self, fpath) -> str:
        return " ".join([self.__repr__(), fpath])

    def __repr__(self) -> str:
        return self.cksum.hexdigest().upper()
